@@ -65,6 +65,7 @@ _service_endpoints_template = {
     'sagemaker-runtime': '{proto}://{host}:4609',
     'ecr': '{proto}://{host}:4610',
     'qldb': '{proto}://{host}:4611',
+    'qldb-session': '{proto}://{host}:4611',
     'cloudtrail': '{proto}://{host}:4612',
     'glacier': '{proto}://{host}:4613',
     'batch': '{proto}://{host}:4614',
@@ -93,10 +94,13 @@ _service_endpoints_template = {
     'appconfig': '{proto}://{host}:4632',
     'ce': '{proto}://{host}:4633',
     'mediaconvert': '{proto}://{host}:4634',
-    'resourcegroupstaggingapi':'{proto}://{host}:4635',
+    'resourcegroupstaggingapi': '{proto}://{host}:4635',
     'resource-groups': '{proto}://{host}:4636',
     'efs': '{proto}://{host}:4637',
-    'backup': '{proto}://{host}:4638'
+    'backup': '{proto}://{host}:4638',
+    'lakeformation': '{proto}://{host}:4639',
+    'waf': '{proto}://{host}:4640',
+    'wafv2': '{proto}://{host}:4640',
 }
 
 # TODO remove service port mapping above entirely
